flask_dependant
=====

flask_dependant是拷贝和参照了`fastapi`中[dependencis](https://fastapi.tiangolo.com/tutorial/dependencies/)中实现和思想,并迁到了flask中。

Installing
----------
`pip3 install -e git+https://github.com/guwenjiang85/flask-dependant.git#egg=flask_dependant`


Requires
---------
```
python>=3.6
flask>=2.0 
pydantic>=1.8,<2.0.0
```

Examples
---------


